act

package
v0.0.0-...-08ad0f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package act provides transport-agnostic abstractions for building actions that can be exposed via HTTP, CLI, or other interfaces.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Action

type Action[I Input, O any, D Deps] func(context.Context, I, D) (*O, error)

Action is a transport-agnostic operation.

type Deps

type Deps any

Deps is a marker type for dependency containers.

type InitDeps

type InitDeps[D Deps] func(context.Context) (D, error)

InitDeps initializes dependencies from context.

type Input

type Input interface {
	Validate() error
}

Input is a validated input type (request, config, etc.)

type NoDeps

type NoDeps struct{}

NoDeps is a zero-value dependency container.

func NoDepsInit

func NoDepsInit(context.Context) (*NoDeps, error)

NoDepsInit is an InitDeps that returns NoDeps.

type NoOutput

type NoOutput struct{}

NoOutput is a zero-value output for actions that only produce side effects.

Directories

Path Synopsis
api
Package cli provides utilities for building CLI commands using the act framework.
Package cli provides utilities for building CLI commands using the act framework.

Jump to