package
Version:
v0.0.0-...-fcb1105
Opens a new window with list of versions in this module.
Published: Apr 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Command creates a new view-session command instance.
Handler contains the business logic for viewing a session.
Config holds all configuration for the view-session command.
Validate ensures the configuration is valid.
type Deps struct {
IO cli.IO
}
Deps holds dependencies for the command.
InitDeps initializes Deps.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.