package
Version:
v0.0.0-...-08ad0f2
Opens a new window with list of versions in this module.
Published: Apr 3, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package act provides transport-agnostic abstractions for building actions
that can be exposed via HTTP, CLI, or other interfaces.
Action is a transport-agnostic operation.
Deps is a marker type for dependency containers.
InitDeps initializes dependencies from context.
type Input interface {
Validate() error
}
Input is a validated input type (request, config, etc.)
NoDeps is a zero-value dependency container.
NoDepsInit is an InitDeps that returns NoDeps.
NoOutput is a zero-value output for actions that only produce side effects.
Source Files
¶
Directories
¶
|
|
|
|
|
|
Package cli provides utilities for building CLI commands using the act framework.
|
Package cli provides utilities for building CLI commands using the act framework. |
Click to show internal directories.
Click to hide internal directories.